@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.13"
+#define LIBXSLT_DOTTED_VERSION "1.0.18"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10013
+#define LIBXSLT_VERSION 10018
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10013"
+#define LIBXSLT_VERSION_STRING "10018"
 
 /**
  * WITH_XSLT_DEBUG:
@@ -73,7 +73,9 @@ extern "C" {
  * On by default unless --without-debugger is passed to configure
  */
 #if 1
-#define WITH_XSLT_DEBUGGER
+#ifndef WITH_DEBUGGER
+#define WITH_DEBUGGER
+#endif
 #endif
 
 /**
